Customization — Django Suit 0.2.21 documentation

# Customization

You can customize Django Suit behaviour by adding `SUIT_CONFIG` configuration variable to your Django project `settings.py` file.

- Configuration
  - Templates
  - Customization
  - Full example
  - Header
    - ADMIN_NAME
    - HEADER_DATE_FORMAT
    - HEADER_TIME_FORMAT
  - Forms
    - SHOW_REQUIRED_ASTERISK
    - CONFIRM_UNSAVED_CHANGES
  - Menu
    - SEARCH_URL
    - MENU_OPEN_FIRST_CHILD
    - MENU_ICONS
    - MENU_EXCLUDE
    - MENU_ORDER
    - MENU
  - List
    - LIST_PER_PAGE

# Templates

You must extend `base_site.html` template to customize footer links, copyright text or to add extra JS/CSS files. Example file is available on github.

Copy customized `base_site.html` template file to your project’s main application `templates/admin/` directory and un-comment and edit the blocks you would like to extend.

Alternatively you can copy `base_site.html` to any of template directories, which are defined in `TEMPLATE_DIRS` setting (if any). By default Django looks in every registered application `templates/` dir.

In the same way you can override any of Django Suit admin templates. More about customizing project’s templates, you can read in Django Admin Tutorial